unix: fix TestStatFieldNames on aix and TestUtimesNanoAt on darwin

Following CL 175157 which renames Stat_t time fields to [AMCB]tim.

Updates golang/go#31735

Change-Id: I0791c59bab307d237b315c1b919265902f7d9917
Reviewed-on: https://go-review.googlesource.com/c/sys/+/177437
Reviewed-by: Ian Lance Taylor <iant@golang.org>
Reviewed-by: Brad Fitzpatrick <bradfitz@golang.org>
Run-TryBot: Brad Fitzpatrick <bradfitz@golang.org>
TryBot-Result: Gobot Gobot <gobot@golang.org>
diff --git a/unix/syscall_test.go b/unix/syscall_test.go
index f2d147c..e20781e 100644
--- a/unix/syscall_test.go
+++ b/unix/syscall_test.go
@@ -62,9 +62,13 @@
 // Test that this compiles. (Issue #31735)
 func TestStatFieldNames(t *testing.T) {
 	var st unix.Stat_t
-	var ts *unix.Timespec
+	var ts interface{} // either *unix.Timespec or *unix.StTimespec on GOOS==aix
 	ts = &st.Atim
 	ts = &st.Mtim
 	ts = &st.Ctim
 	_ = ts
+	secs := int64(st.Mtim.Sec)
+	nsecs := int64(st.Mtim.Nsec)
+	_ = secs
+	_ = nsecs
 }
diff --git a/unix/syscall_darwin_test.go b/unix/syscall_darwin_test.go
index a8a5d4e..f24273d 100644
--- a/unix/syscall_darwin_test.go
+++ b/unix/syscall_darwin_test.go
@@ -50,15 +50,15 @@
 		t.Fatalf("Lstat: %v", err)
 	}
 
 	// Only check Mtimespec, Atimespec might not be supported by the underlying filesystem
 	expected := ts[1]
-	if st.Mtimespec.Nsec == 0 {
+	if st.Mtim.Nsec == 0 {
 		// Some filesystems only support 1-second time stamp resolution
 		// and will always set Nsec to 0.
 		expected.Nsec = 0
 	}
-	if st.Mtimespec != expected {
-		t.Errorf("UtimesNanoAt: wrong mtime: got %v, expected %v", st.Mtimespec, expected)
+	if st.Mtim != expected {
+		t.Errorf("UtimesNanoAt: wrong mtime: got %v, expected %v", st.Mtim, expected)
 	}
 }
 
@@ -50,15 +50,15 @@
 	}
 
-	// Only check Mtimespec, Atimespec might not be supported by the underlying filesystem
+	// Only check Mtim, Atim might not be supported by the underlying filesystem
 	expected := ts[1]